var NAVTREEINDEX4 =
{
"link_8h.html#aa90bcda1ac9edbb5f2c92703f1e38d84":[11,0,37,14],
"link_8h.html#aafb6d5e113016baef0cf9a8cc9405c31":[11,0,37,10],
"link_8h.html#ab53c62332a757ed234d5eb91a54a23ac":[11,0,37,3],
"link_8h_source.html":[11,0,37],
"log_8c.html":[11,0,38],
"log_8c.html#a0c36ced32d7c93e93a7546e6b95ab79e":[11,0,38,1],
"log_8c.html#ae98f1a3c52f402a7004bf30bc64f3ced":[11,0,38,2],
"log_8c.html#afb19ed665807eb04101898b6548a614e":[11,0,38,0],
"log_8h.html":[11,0,39],
"log_8h.html#a0a957072ba799bbf2bdc77501ccd81d0":[11,0,39,5],
"log_8h.html#a0baff5cd026e7187ab12ca821f942502":[11,0,39,10],
"log_8h.html#a2d2c2dc7d35b7104f5caef08df416767":[11,0,39,7],
"log_8h.html#a2e4a80353dce36ba723a5401299c6673":[11,0,39,11],
"log_8h.html#a388c36c000f2aac0658e75f17cabeda4":[11,0,39,9],
"log_8h.html#a66c4dbcfe71f20642b74e4ec1576ac2a":[11,0,39,4],
"log_8h.html#a8786c346982e4bd15af22d180e091699":[11,0,39,8],
"log_8h.html#a97a1a2e0ffd63e3f859b1ab183b379c3":[11,0,39,6],
"log_8h.html#a98a49c37f11de525890014e927e34d02":[11,0,39,1],
"log_8h.html#a995a5e0ef414e9246fbf2ad56b0ce281":[11,0,39,2],
"log_8h.html#a9f7889d134dd808e0b3609c7e694ad3a":[11,0,39,12],
"log_8h.html#aaa7a8d5ecdd95e45af3d48d798a3d4af":[11,0,39,3],
"log_8h.html#ac5f33d3392f3df466736240c534f5dfe":[11,0,39,13],
"log_8h.html#aee4279818cb86e638cd2bfd79973ce87":[11,0,39,0],
"log_8h_source.html":[11,0,39],
"loop_8c.html":[11,0,40],
"loop_8c.html#a47f2e62c0dbebc787052c165afcada0e":[11,0,40,1],
"loop_8c.html#a7217634bf59cc77958e725767e80f754":[11,0,40,0],
"loop_8h.html":[11,0,41],
"loop_8h.html#a101116180c84c3ddcad44d06e546e117":[11,0,41,15],
"loop_8h.html#a12545a7e053006bf3865618edb6cf275":[11,0,41,10],
"loop_8h.html#a1dd2c1af93f7bcb43f983f779866c639":[11,0,41,21],
"loop_8h.html#a358a963dac14b2f6b57404b3fb13bb05":[11,0,41,19],
"loop_8h.html#a509d8e5f87cb79816ac99afd2765b0e6":[11,0,41,13],
"loop_8h.html#a5789fb95e8a0ddd1c4cf8d0143878551":[11,0,41,11],
"loop_8h.html#a5ca87923bfa2820ee6e73fbf890bac54":[11,0,41,8],
"loop_8h.html#a5e937f4e92704c5b7924c07605d06318":[11,0,41,7],
"loop_8h.html#a6edef1937eb5fc176a6a36485eebf8ad":[11,0,41,4],
"loop_8h.html#a714ada0b1d2d9092d4e659731ccc4cb8":[11,0,41,5],
"loop_8h.html#a8bea041a509d072fbc54cccdb842944a":[11,0,41,9],
"loop_8h.html#a8f6b6e07508edcd3413a05deb93b1bc0":[11,0,41,14],
"loop_8h.html#a9cd661d2b33b7032f826c58614e91cfd":[11,0,41,3],
"loop_8h.html#aa26ce5ccf840db64b7e1de4b3f57de6e":[11,0,41,16],
"loop_8h.html#abb397780fe21d077fa89d46e187e0ecb":[11,0,41,2],
"loop_8h.html#ac2a7224b391a302d02f75c4803c7f588":[11,0,41,6],
"loop_8h.html#ac62ac71350289ac2b1a312761b2bb82c":[11,0,41,1],
"loop_8h.html#ad531597a43cad4669d627b2226011067":[11,0,41,18],
"loop_8h.html#ade78a07ed3f7a7cb6280485224d65709":[11,0,41,20],
"loop_8h.html#afd0bce4fa062fe5906318bbfa9442d0f":[11,0,41,17],
"loop_8h.html#afff39c7f964a4b011c4fc589c6a6ec92":[11,0,41,12],
"loop_8h_source.html":[11,0,41],
"main-loop_8c.html":[11,0,42],
"main-loop_8c.html#a3f816398436d773de7e5b8690ea595a0":[11,0,42,2],
"main-loop_8c.html#a47f2e62c0dbebc787052c165afcada0e":[11,0,42,0],
"main-loop_8c.html#aab60032b3da5bb2b32ddf41e33389a2f":[11,0,42,1],
"main-loop_8h.html":[11,0,43],
"main-loop_8h.html#a1aa05322e2691673b12d71734acd8f89":[11,0,43,5],
"main-loop_8h.html#a3310e380c0368cb007552027a040ff96":[11,0,43,1],
"main-loop_8h.html#a364190789f9f07251fe2c8ee45f5d1c1":[11,0,43,6],
"main-loop_8h.html#a4248c0e1da7ea6a1f7a4df7cbdc2db72":[11,0,43,3],
"main-loop_8h.html#a4cc23752fe4d60ae07d98a481e03734b":[11,0,43,7],
"main-loop_8h.html#ae2ca7b19516a0245b0da1756a82ca753":[11,0,43,2],
"main-loop_8h.html#af0fc490ae11b6409e2bbc0838c8becdd":[11,0,43,4],
"main-loop_8h_source.html":[11,0,43],
"map_8h.html":[11,0,44],
"map_8h.html#a0b288cc2632c67d0ea9f6891baf3ab54":[11,0,44,2],
"map_8h.html#a2ef0d619ea803c94409128752bb89763":[11,0,44,4],
"map_8h.html#a3e84b47d125ced3009966a174bb256fa":[11,0,44,7],
"map_8h.html#a68baeb8bdb9f86831c82ce4115bc65ef":[11,0,44,5],
"map_8h.html#a7060d2d1b6d51f457b25f1ff1143ab1e":[11,0,44,10],
"map_8h.html#a91899b8a60f9dddea1580fd68aa1ae5f":[11,0,44,11],
"map_8h.html#ab8be77b792f9714ce04160c5a5cbcfac":[11,0,44,8],
"map_8h.html#abbbe18fa2f93752c95f83ccac5a8e9a6":[11,0,44,9],
"map_8h.html#ac7d645f3b51c4be5a442464a5d8132cf":[11,0,44,6],
"map_8h.html#ae4711748f39e5e8235faf961f35fb8a2":[11,0,44,3],
"map_8h_source.html":[11,0,44],
"mem_8c.html":[11,0,45],
"mem_8c.html#a0d7e40a9933d11da2fc1b0b1b863eec3":[11,0,45,5],
"mem_8c.html#a1d9ebf7ab094a827cd93d1e49e81e8a0":[11,0,45,11],
"mem_8c.html#a1eac736570d41ffac78ec7c5caa8ca25":[11,0,45,17],
"mem_8c.html#a21cda477fe5bf4681ccf6869acf96d20":[11,0,45,30],
"mem_8c.html#a277a61f49a8c8e232bb3af723af1fb3f":[11,0,45,25],
"mem_8c.html#a3268e6d65db2950f67f6082946d16952":[11,0,45,12],
"mem_8c.html#a3318c5821ce251c9c3c16145bed41647":[11,0,45,19],
"mem_8c.html#a3c9cb62957637bb3b3a869cbbe5e4aaa":[11,0,45,4],
"mem_8c.html#a47f2e62c0dbebc787052c165afcada0e":[11,0,45,13],
"mem_8c.html#a54af789ad65b83449d415dbfb7d39481":[11,0,45,6],
"mem_8c.html#a5c298052be6fe8f5f4ea78b4fe41733d":[11,0,45,21],
"mem_8c.html#a5f75d7faa910a02718a9ecf3f9c4041c":[11,0,45,33],
"mem_8c.html#a68a01fe6f7305883d5f15ddfd1ebfd84":[11,0,45,8],
"mem_8c.html#a6ae683cd27bb82613d1c025277b69b48":[11,0,45,7],
"mem_8c.html#a6d863d10f2d358484936fd382f55b9b5":[11,0,45,24],
"mem_8c.html#a7066384a72de880e75a1b922d2d62dd2":[11,0,45,31],
"mem_8c.html#a82af8008b212e99dd3a8b8daa2138170":[11,0,45,10],
"mem_8c.html#a98ea0829a6ae8b9adb9910457f4ca4cd":[11,0,45,9],
"mem_8c.html#a9cb98e289a2f39ad7874243e905d9daf":[11,0,45,26],
"mem_8c.html#a9e39d964e7ba4d39449cb8b569504a3e":[11,0,45,22],
"mem_8c.html#aa3b33676b8bd10a4280ec5f9a4f86831":[11,0,45,18],
"mem_8c.html#ab253128cb2d2bc7ad5203d2b65e762c8":[11,0,45,23],
"mem_8c.html#abfda07a34439c7edfc8c2cb7fe9576a3":[11,0,45,28],
"mem_8c.html#ac19e242f78a043eb56e57009cf87623e":[11,0,45,29],
"mem_8c.html#ad2d67640ddabf8a7f530053ebca34abf":[11,0,45,15],
"mem_8c.html#ad9bd7205a3e7a88320624ef7addbfe9f":[11,0,45,16],
"mem_8c.html#ada787db75d4f0040104f59210fbcfdac":[11,0,45,20],
"mem_8c.html#ae5e42242439fef39fd696db151642513":[11,0,45,32],
"mem_8c.html#aee8f104fd65b3d11fef242883a787657":[11,0,45,14],
"mem_8c.html#af289ae70c84c5f467bf04371dac6d6fa":[11,0,45,27],
"mem_8h.html":[11,0,46],
"mem_8h.html#a129ecc0ee25039116cc99c138e16c4c6":[11,0,46,9],
"mem_8h.html#a1daf40887c9a63347e9c59822287747a":[11,0,46,7],
"mem_8h.html#a1daf40887c9a63347e9c59822287747aa58334ee09eeba50b788a04f276440475":[11,0,46,7,1],
"mem_8h.html#a1daf40887c9a63347e9c59822287747aa5e15b1dc0d4d0354a37a841af139411b":[11,0,46,7,5],
"mem_8h.html#a1daf40887c9a63347e9c59822287747aa8b0a302b83a9d3cd11e2b6ed7f82f546":[11,0,46,7,2],
"mem_8h.html#a1daf40887c9a63347e9c59822287747aac3e5ceea50faacf9d2aac1670f07fd65":[11,0,46,7,0],
"mem_8h.html#a1daf40887c9a63347e9c59822287747aaf12060ee3328912e62d05650edaa999a":[11,0,46,7,3],
"mem_8h.html#a1daf40887c9a63347e9c59822287747aafa1af7ca17efbe9d9104e0e9e25996bf":[11,0,46,7,4],
"mem_8h.html#a3dbe2152d1ae85434bf57f58e6c37043":[11,0,46,6],
"mem_8h.html#a3efb664909dd90a771d5092238a7a603":[11,0,46,10],
"mem_8h.html#a3f4c9504cb9f261727ec4b27d0b7074d":[11,0,46,12],
"mem_8h.html#a40f7779f907ebc367725ba5c7c8b0f88":[11,0,46,20],
"mem_8h.html#a5c298052be6fe8f5f4ea78b4fe41733d":[11,0,46,11],
"mem_8h.html#a5f75d7faa910a02718a9ecf3f9c4041c":[11,0,46,24],
"mem_8h.html#a637115c056f47906c4d52faf043e415f":[11,0,46,17],
"mem_8h.html#a85ef7c8290e81beb53ab9e1c7b44ff29":[11,0,46,21],
"mem_8h.html#a8cefbc9877517111668c36f24edb2dfd":[11,0,46,16],
"mem_8h.html#a9d831e5773c3aa8ac62d72f6e4a161b7":[11,0,46,5],
"mem_8h.html#a9e39d964e7ba4d39449cb8b569504a3e":[11,0,46,13],
"mem_8h.html#aa706ad494480f45ba0683ee91b2779d1":[11,0,46,8],
"mem_8h.html#aa9b5475f99e223a1b20d1d1b79549381":[11,0,46,22],
"mem_8h.html#ab253128cb2d2bc7ad5203d2b65e762c8":[11,0,46,14],
"mem_8h.html#acc1fb3bb1d96fa7ee1b6850eb865ebe6":[11,0,46,19],
"mem_8h.html#adc0de7b22a2892cdf9582fbcf6f4b712":[11,0,46,15],
"mem_8h.html#ae5e42242439fef39fd696db151642513":[11,0,46,23],
"mem_8h.html#af11ea8ae8c13e394c39d7bf035be4f7b":[11,0,46,18],
"mem_8h_source.html":[11,0,46],
"module_8h.html":[11,0,47],
"module_8h.html#a408cf508aabe2366f9134f443b186bcf":[11,0,47,11],
"module_8h.html#a453e9a4a774060bb10973e607213d64a":[11,0,47,3],
"module_8h.html#a6e930a12dde7bbf70d6909c634af9d97":[11,0,47,12],
"module_8h.html#a6fe9156c393377696bc3d03107bcf288":[11,0,47,8],
"module_8h.html#a847ff9b82e7218db4383444fbdc11b51":[11,0,47,10],
"module_8h.html#a9a9305a5898d1480d8a542f300743ed6":[11,0,47,5],
"module_8h.html#a9f006acecf3988802d7bd35600b3cfba":[11,0,47,14],
"module_8h.html#aaf5d15bb2ee832cc2beb1f0c2921ef8c":[11,0,47,4],
"module_8h.html#ab095f436fa3ebb521f692fb6bf99c79f":[11,0,47,6],
"module_8h.html#ad670c8d581f68d016f475c12cff250c8":[11,0,47,13],
"module_8h.html#ad6d3cbf77b94e229ef370635889b8121":[11,0,47,7],
"module_8h.html#ae35020db0760ef496a5fbe14745fd56b":[11,0,47,9],
"module_8h_source.html":[11,0,47],
"node_8h.html":[11,0,48],
"node_8h.html#a0093e032db467e20f79767260fa1758e":[11,0,48,27],
"node_8h.html#a027e0d76dfb4448a29d718bec066b409":[11,0,48,15],
"node_8h.html#a03964e24225bdf9a290590cd30ad664a":[11,0,48,22],
"node_8h.html#a0ee148738da978c59c3afaf91215db71":[11,0,48,29],
"node_8h.html#a111891241c623bdfe86ba5e1811f374e":[11,0,48,5],
"node_8h.html#a125b3c8bae9656635dd9c24febbe221f":[11,0,48,24],
"node_8h.html#a13f0cb22b45e8f81e709b84ff3b1fde7":[11,0,48,7],
"node_8h.html#a1977da2214d00db4a4d50202da3a2c35":[11,0,48,17],
"node_8h.html#a3add61d46ad7b1daa86792cbeafc6090":[11,0,48,18],
"node_8h.html#a3c668f349296e6fcbf3b294b92274f1f":[11,0,48,10],
"node_8h.html#a3c78657690ffa3263238181bbe7073e4":[11,0,48,12],
"node_8h.html#a3db541c9ec1c2245fe17402135979f2d":[11,0,48,8],
"node_8h.html#a5437fe007ac346f48f0f63fec8ca8b40":[11,0,48,16],
"node_8h.html#a551b316bd8df6636cd863b82d3f006e3":[11,0,48,3],
"node_8h.html#a5768e66e04bfef45e468df3e38158c93":[11,0,48,23],
"node_8h.html#a576eec63e376281ca762c48b00b7eba3":[11,0,48,30],
"node_8h.html#a593a4f2610442e1956052f5c13de02f2":[11,0,48,26],
"node_8h.html#a6ac60f95cc0fdb6d769df30cce34901c":[11,0,48,21],
"node_8h.html#a6b2101857ce7cd58fa7024afa281a730":[11,0,48,19],
"node_8h.html#a7f79a67df47a08661d622c1ca73571ea":[11,0,48,4],
"node_8h.html#a8f11f362e3c9cda9d9fba69ed37f9c9b":[11,0,48,14],
"node_8h.html#a91a6a1a257b75f8a6fd5eb6755447a59":[11,0,48,6],
"node_8h.html#a9d39e0829f4a14185dc242d5c362b9de":[11,0,48,9],
"node_8h.html#ac3a4cf514e46d1e590ad45fd3e8d7813":[11,0,48,11],
"node_8h.html#ac493839c0b0a1d0b935969f2e990a2df":[11,0,48,28],
"node_8h.html#ac493839c0b0a1d0b935969f2e990a2dfa316510257c8a6afc788c415cc3288ad2":[11,0,48,28,0],
"node_8h.html#ac493839c0b0a1d0b935969f2e990a2dfa715c586abce5cbbc09db32145a51e82f":[11,0,48,28,2],
"node_8h.html#ac493839c0b0a1d0b935969f2e990a2dfa801ee69d0b0c9d30b12ff89daae9a075":[11,0,48,28,3],
"node_8h.html#ac493839c0b0a1d0b935969f2e990a2dfaa73a63afebf017a0c0afdea192b1691c":[11,0,48,28,1],
"node_8h.html#ac493839c0b0a1d0b935969f2e990a2dfaa9c88f01497f82d9ffc4605dae27e93a":[11,0,48,28,4],
"node_8h.html#ae34dde148d3ae268808d68926a8a2da4":[11,0,48,25],
"node_8h.html#aea23ddf2322c57e3cca4a7d40144bda8":[11,0,48,20],
"node_8h.html#af8cda535f0a1e63b1074f859cf650525":[11,0,48,13],
"node_8h_source.html":[11,0,48],
"page_client.html":[3,3],
"page_client.html#sec_page_client_credentials":[3,3,1],
"page_client.html#sec_page_client_overview":[3,3,0],
"page_client.html#sec_page_client_resources":[3,3,3],
"page_client.html#sec_page_client_types":[3,3,2],
"page_context.html":[3,1],
"page_context_api.html":[3],
"page_context_api.html#page_context_overview":[3,0],
"page_control.html":[4],
"page_control.html#page_control_overview":[4,0],
"page_global.html":[3,2],
"page_iface_pw_core.html":[5],
"page_iface_pw_core.html#page_iface_pw_core":[5,1],
"page_iface_pw_core.html#page_iface_pw_core_desc":[5,0],
"page_link.html":[3,7],
"page_link.html#page_link_overview":[3,7,0],
"page_node.html":[3,5],
"page_node.html#page_node_overview":[3,5,0],
"page_port.html":[3,6],
"page_proxy.html":[7],
"page_proxy.html#sec_page_proxy_bind":[7,3],
"page_proxy.html#sec_page_proxy_core":[7,1],
"page_proxy.html#sec_page_proxy_create":[7,2],
"page_proxy.html#sec_page_proxy_destroy":[7,6],
"page_proxy.html#sec_page_proxy_events":[7,5],
"page_proxy.html#sec_page_proxy_methods":[7,4],
"page_proxy.html#sec_page_proxy_overview":[7,0],
"page_registry.html":[6],
"page_registry.html#page_registry_overview":[6,0],
"page_resource.html":[3,4],
"page_resource.html#sec_page_resource":[3,4,0],
"page_streams.html":[8],
"page_streams.html#sec_buffers":[8,4],
"page_streams.html#sec_connect":[8,2],
"page_streams.html#sec_create":[8,1],
"page_streams.html#sec_format":[8,3],
"page_streams.html#sec_overview":[8,0],
"page_streams.html#sec_stream_disconnect":[8,6],
"page_streams.html#sec_streaming":[8,5],
"page_streams.html#ssec_consume":[8,5,0],
"page_streams.html#ssec_produce":[8,5,1],
"page_streams.html#ssec_stream_formats":[8,2,1],
"page_streams.html#ssec_stream_target":[8,2,0],
"page_thread_loop.html":[9],
"page_thread_loop.html#sec_thread_loop_create":[9,1],
"page_thread_loop.html#sec_thread_loop_destruction":[9,2],
"page_thread_loop.html#sec_thread_loop_events":[9,4],
"page_thread_loop.html#sec_thread_loop_locking":[9,3],
"page_thread_loop.html#sec_thread_loop_overview":[9,0],
"pages.html":[],
"permission_8h.html":[11,0,49],
"permission_8h.html#a2668b1c9a4b1e4b68fefe81e55d1ee59":[11,0,49,2],
"permission_8h.html#a277828556118843e682c652bb1dc9c8e":[11,0,49,8],
"permission_8h.html#a2a31ac243ad99915377319b663daf426":[11,0,49,5],
"permission_8h.html#a50224a8e3d16e9baa4be58183fec502f":[11,0,49,1],
"permission_8h.html#a5dca3f2e9a9b71cc78525893eb80355b":[11,0,49,4],
"permission_8h.html#a77df16320c3bb338666f55b2b21e6e47":[11,0,49,6],
"permission_8h.html#a97d33a5e044ee126fd9991b8c70424aa":[11,0,49,7],
"permission_8h.html#aa61804de7cf6003defd8b26ef488ce56":[11,0,49,3],
"permission_8h.html#aa6b729cf828ec6417f5ba997560fda2b":[11,0,49,9],
"permission_8h_source.html":[11,0,49],
"pipewire_8c.html":[11,0,50],
"pipewire_8c.html#a11740ad8a800f1b866e3af11e02762c8":[11,0,50,6],
"pipewire_8c.html#a5432ea68283040ae9df24ebefe6414aa":[11,0,50,5],
"pipewire_8c.html#aa060eea150eca4951bf30b2738493912":[11,0,50,8],
"pipewire_8c.html#ac0edd7fd875859cef79624861e212cc8":[11,0,50,7],
"pipewire_8c.html#acbb97d3ccaef2d8793ec48242324bf15":[11,0,50,10]
};
